<template>
  <div>
    <van-sticky>
      <van-nav-bar
        title="案件督办"
        left-arrow
        @click-left="_ => $router.go(-1)"
      >
      </van-nav-bar>
    </van-sticky>
    <div class="search">
      <van-dropdown-menu class="dropdown">
        <van-dropdown-item
          style="width:35%"
          v-model="querys[0].value"
          :options="caseNodeLsit"
          @change="onSearch"
        />
      </van-dropdown-menu>
      <van-search
        style="width:65%"
        v-model="querys[1].value"
        placeholder="请输入案件编号"
        @blur="onSearch"
      />
    </div>
    <van-list
      style="padding-top: 4rem;box-sizing: border-box;"
      v-model="loading"
      :finished="finished"
      finished-text="没有更多了"
      @load="onLoad"
    >
      <div class="table-item" v-for="(item, index) in list" :key="index">
        <div class="title">
          <div>
            <div class="tags">
              {{ getDictName('tybagl-ajyxhj', item.caseType) }}
            </div>
            {{ item.caseCode }}
          </div>
          <div class="tag">
            {{ getDictName('tybagl-ajlx', item.caseType) }}
          </div>
          <!-- <div>
            <van-tag
              v-if="item.superviseNode == '1'"
              color="#999"
              text-color="#fff"
              >立案</van-tag
            >
            <van-tag
              v-else-if="item.superviseNode == '2'"
              color="#999"
              text-color="#fff"
              >调查取证</van-tag
            >
            <van-tag v-else-if="item.superviseNode == '3'" type="primary"
              >处罚决定</van-tag
            >
            <van-tag
              v-else-if="item.superviseNode == '4'"
              color="#999"
              text-color="#fff"
              >结案</van-tag
            >
          </div> -->
        </div>
        <div class="two-title">督办领导名称：{{ item.leaderName }}</div>
        <div class="two-title">
          承办人员所属部门名称：{{ item.handleDeptName }}
        </div>
        <div class="urgency-settings">
          <div class="two-title">承办人员名称：{{ item.handleUserName }}</div>
          <div class="btn" @click.stop="toDetail(item)">督办</div>
        </div>
      </div>
    </van-list>
  </div>
</template>
<script>
import api from '@/api/device/supervisionCase.js'
import dictUtils from '@/components/dict/DictSelectUtils'

export default {
  name: 'caseExamine',
  data() {
    return {
      loginname: '',
      value: '',
      value1: '',
      options: [
        {text: '全部', value: ''},
        {text: '立案', value: '1'},
        {text: '调查取证 ', value: '2'},
        {text: '处罚决定 ', value: '3'},
        {text: '结案 ', value: '5'}
      ],
      caseNodeLsit: [],
      list: [],
      loading: false,
      finished: false,
      total: 0,
      querys: [
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'superviseNode',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'case_code_',
          relation: 'AND',
          value: ''
        }
      ],
      queryParam: {
        pageBean: {
          pageSize: 0,
          page: 1
        },
        params: {},
        querys: []
      }
    }
  },
  created() {
    this.caseNodeLsit = dictUtils
      .getDictItemsFromCache('tybagl-ajyxhj')
      .map(item => {
        return {
          text: item.name,
          value: item.value
        }
      })
    this.caseNodeLsit.unshift({
      text: '全部阶段',
      value: ''
    })
  },
  mounted() {
  },

  methods: {
    onLoad() {
      setTimeout(() => {
        this.queryParam.pageBean.pageSize += 10
        this.getData()
        this.loading = false
      }, 500)
    },
    onSearch() {
      this.queryParam.pageBean.pageSize = 10
      this.finished = false
      this.getData()
    },
    getData() {
      this.queryParam.querys = []
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      api.queryData(this.queryParam, res => {
        if (res.rows) {
          this.list = res.rows
          this.total = res.total
          if (this.list.length >= this.total) {
            this.finished = true
          }
        } else {
          this.finished = true
        }
      })
    },
    toDetail(val) {
      this.$router.push({name: 'supervisionCaseDetail', query: {val: val}})
    }
  }
}
</script>
<style scoped lang="scss">
.search {
  width: 100%;
  position: fixed;
  display: flex;
  background-color: #fff;
  justify-content: space-between;
  top: 4rem;
  box-shadow: 0 2px 12px rgba(100, 101, 102, 0.12);

  .dropdown {
    box-shadow: none;
    width: 30%;
  }
}

.table-item {
  background: #fff;
  box-shadow: 0 0 0.5rem 0.2rem rgba(82, 81, 81, 0.11);
  border-radius: 1rem;
  margin: 1rem 0.7rem;
  padding: 1rem 0;
  box-sizing: border-box;

  .title {
    display: flex;
    justify-content: space-between;
    padding: 0 1rem;

    div:nth-child(1) {
      font-weight: bold;
    }
  }

  .bun {
    width: 100%;
    border-top: #f7f7f7 solid 1px;

    text-align: center;
    padding: 1rem 0;
    color: #469ff7;

    span {
      font-size: 16px !important;
    }
  }

  .two-title {
    color: #7e7d7d;
    line-height: 2rem;
    padding: 0 1rem;
  }

  .urgency-settings {
    padding: 0 1rem 0 0;
    display: flex;
    justify-content: space-between;

    .btn {
      display: flex;
      justify-content: center;
      align-items: center;
      width: 400px;
      color: #1a89fa;
      border-radius: 100px;
      border: #1a89fa 1px solid;
      // background-color: #1a89fa;
    }
  }
}

.tag {
  display: inline-block;
  background-color: #1a89fa;
  padding: 10px 0.4rem;
  border-radius: 0.4rem;
  box-sizing: border-box;
  color: #fff;
}

.tags {
  display: inline-block;
  border: #1a89fa 1px solid;
  padding: 10px 0.4rem;
  border-radius: 0.4rem;
  box-sizing: border-box;
  color: #1a89fa;
}

::v-deep .van-search {
  padding: 0;
}

::v-deep .van-dropdown-menu__bar {
  box-shadow: none;
}

::v-deep .van-tag {
  position: static;
}
</style>
